namespace AirFighter
{
    public partial class FormAirFighter : Form
    {
        private DrawingAirFighter _airFighter;

        public DrawingAirFighter SelectedAirFighter { get; private set; }

        public FormAirFighter()
        {
            InitializeComponent();
        }
        
        private void SetData(DrawingAirFighter airFighter)
        {
            toolStripStatusLabelSpeed.Text = $": {_airFighter.AirFighter.Speed}";
            toolStripStatusLabelWeight.Text = $": {_airFighter.AirFighter.Weight}";
            toolStripStatusLabelBodyColor.Text = $": { _airFighter.AirFighter.BodyColor.Name}";
        }

        private void CreateButton_Click(object sender, EventArgs e)
        {
            Random rnd = new();
            Color color = Color.FromArgb(rnd.Next(0, 256), rnd.Next(0, 256),
           rnd.Next(0, 256));
            ColorDialog dialog = new();
            if (dialog.ShowDialog() == DialogResult.OK)
            {
                color = dialog.Color;
            }
            _airFighter = new DrawingAirFighter(rnd.Next(100, 300), rnd.Next(1000, 2000), color);

            _airFighter.SetPosition(rnd.Next(10, 100), rnd.Next(10, 100), pictureBox.Width, pictureBox.Height);

            SetData(_airFighter);
            Draw();
        }

        private void CreateModernButton_Click(object sender, EventArgs e)
        {
            Random rnd = new();
            Color color = Color.FromArgb(rnd.Next(0, 256), rnd.Next(0, 256), rnd.Next(0, 256));
            ColorDialog dialog = new();
            if (dialog.ShowDialog() == DialogResult.OK)
            {
                color = dialog.Color;
            }
            Color dopColor = Color.FromArgb(rnd.Next(0, 256), rnd.Next(0, 256), rnd.Next(0, 256));
            ColorDialog dialogDop = new();
            if (dialogDop.ShowDialog() == DialogResult.OK)
            {
                dopColor = dialogDop.Color;
            }
            _airFighter = new DrawingModernAirFighter(rnd.Next(100, 300), rnd.Next(1000, 2000),
            color, dopColor,
            Convert.ToBoolean(rnd.Next(0, 2)), Convert.ToBoolean(rnd.Next(0,2)));

            _airFighter.SetPosition(rnd.Next(10, 100), rnd.Next(10, 100), pictureBox.Width, pictureBox.Height);

            SetData(_airFighter);
            Draw();
        }

        private void ButtonMove_Click(object sender, EventArgs e)
        {
            string name = ((Button)sender).Name ?? string.Empty;

            switch(name)
            {
                case "UpButton":
                    _airFighter?.MoveTransport(Direction.Up);
                    break;

                case "LeftButton":
                    _airFighter?.MoveTransport(Direction.Left);
                    break;

                case "DownButton":
                    _airFighter?.MoveTransport(Direction.Down);
                    break;

                case "RightButton":
                    _airFighter?.MoveTransport(Direction.Right);
                    break;
            }

            Draw();
        }

        private void PictureBox_Resize(object sender, EventArgs e)
        {
            _airFighter?.ChangeBorders(pictureBox.Width, pictureBox.Height);
            Draw();
        }

        private void ButtonSelect_Click(object sender, EventArgs e)
        {
            SelectedAirFighter = _airFighter;
            DialogResult = DialogResult.OK;
        }

        public void Draw()
        {
            if (pictureBox.Width == 0 || pictureBox.Height == 0) return;
            Bitmap bmp = new(pictureBox.Width, pictureBox.Height);
            Graphics gr = Graphics.FromImage(bmp);
            _airFighter?.DrawTransport(gr);
            pictureBox.Image = bmp;
        }
    }
}