﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace AirFighter
{
    public partial class FormMapWithSetCars : Form
    {
        private MapWithSetCarsGeneric<DrawingObjectAirFighter, AbstractMap> _mapCarsCollectionGeneric;
        /// <summary>
        /// Конструктор
        /// </summary>
        public FormMapWithSetCars()
        {
            InitializeComponent();
        }
        /// <summary>
        /// Выбор карты
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ComboBoxSelectorMap_SelectedIndexChanged(object sender, EventArgs e)
        {
            AbstractMap map = null;
            switch (comboBoxSelectorMap.Text)
            {
                case "Простая карта":
                    map = new SimpleMap();
                    break;
                case "Моя карта":
                    map = new MyMap();
                    break;
            }
            if (map != null)
            {
                _mapCarsCollectionGeneric = new
               MapWithSetCarsGeneric<DrawingObjectAirFighter, AbstractMap>(
                pictureBox.Width, pictureBox.Height, map);
            }
            else
            {
                _mapCarsCollectionGeneric = null;
            }
        }
        /// <summary>
        /// Добавление объекта
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ButtonAddCar_Click(object sender, EventArgs e)
        {
            if (_mapCarsCollectionGeneric == null)
            {
                return;
            }
            FormAirFighter form = new();
            if (form.ShowDialog() == DialogResult.OK)
            {
                DrawingObjectAirFighter car = new(form.SelectedAirFighter);
                if (_mapCarsCollectionGeneric + car != -1)
                {
                    MessageBox.Show("Объект добавлен");
                    pictureBox.Image = _mapCarsCollectionGeneric.ShowSet();
                }
                else
                {
                    MessageBox.Show("Не удалось добавить объект");
                }
            }
        }
        /// <summary>
        /// Удаление объекта
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ButtonRemoveCar_Click(object sender, EventArgs e)
        {
            if (string.IsNullOrEmpty(maskedTextBoxPosition.Text))
            {
                return;
            }
            if (MessageBox.Show("Удалить объект?", "Удаление",
           MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.No)
            {
                return;
            }
            int pos = Convert.ToInt32(maskedTextBoxPosition.Text);
            if (_mapCarsCollectionGeneric - pos != null)
            {
                MessageBox.Show("Объект удален");
                pictureBox.Image = _mapCarsCollectionGeneric.ShowSet();
            }
            else
            {
                MessageBox.Show("Не удалось удалить объект");
            }
        }
        /// <summary>
        /// Вывод набора
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ButtonShowStorage_Click(object sender, EventArgs e)
        {
            if (_mapCarsCollectionGeneric == null)
            {
                return;
            }
            pictureBox.Image = _mapCarsCollectionGeneric.ShowSet();
        }
        /// <summary>
        /// Вывод карты
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ButtonShowOnMap_Click(object sender, EventArgs e)
        {
            if (_mapCarsCollectionGeneric == null)
            {
                return;
            }
            pictureBox.Image = _mapCarsCollectionGeneric.ShowOnMap();
        }
        /// <summary>
        /// Перемещение
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ButtonMove_Click(object sender, EventArgs e)
        {
            if (_mapCarsCollectionGeneric == null)
            {
                return;
            }
            //получаем имя кнопки
            string name = ((Button)sender)?.Name ?? string.Empty;
            Direction dir = Direction.None;
            switch (name)
            {
                case "UpButton":
                    dir = Direction.Up;
                    break;
                case "DownButton":
                    dir = Direction.Down;
                    break;
                case "LeftButton":
                    dir = Direction.Left;
                    break;
                case "RightButton":
                    dir = Direction.Right;
                    break;
            }
            pictureBox.Image = _mapCarsCollectionGeneric.MoveObject(dir);
        }
    }
}
